CCL: ccl_configuration Struct Reference

CCL

Data Fields
ccl_configuration Struct Reference

`#include <ccl_config.h>`

## Data Fields
transfer_function_t | transfer_function_method
matter_power_spectrum_t | matter_power_spectrum_method
mass_function_t | mass_function_method

## Detailed Description

Configuration typedef. This contains the transfer function, matter power spectrum, and mass function that is being used currently.

## Field Documentation

## ◆ mass_function_method

mass_function_t ccl_configuration::mass_function_method

## ◆ matter_power_spectrum_method

matter_power_spectrum_t ccl_configuration::matter_power_spectrum_method

## ◆ transfer_function_method

transfer_function_t ccl_configuration::transfer_function_method

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_config.h